import React, { useState, useEffect } from 'react';
import OrderForm from './OrderForm';
import OrderSummary from './OrderSummary';
import { StickerType } from '@/hooks/useOrderState';
import './background-placeholder.css';
// Import removed - using direct path instead

interface HeroProps {
  orderState: {
    stickerType: StickerType;
    width: number;
    height: number;
    quantity: number;
    widthUnit: 'cm' | 'mm';
    heightUnit: 'cm' | 'mm';
    installation: 'none' | 'tallinn' | 'outside_tallinn';
    files: File[];
    isModalOpen: boolean;
  };
  updateStickerType: (type: StickerType) => void;
  updateDimensions: (type: 'width' | 'height', value: number, unit?: 'cm' | 'mm') => void;
  updateQuantity: (value: number) => void;
  updateInstallation: (type: 'none' | 'tallinn' | 'outside_tallinn') => void;
  calculatePrice: () => number;
  toggleModal: () => void;
}

const Hero: React.FC<HeroProps> = ({
  orderState,
  updateStickerType,
  updateDimensions,
  updateQuantity,
  updateInstallation,
  calculatePrice,
  toggleModal,
}) => {
  // State to track if the main background image has loaded
  const [backgroundLoaded, setBackgroundLoaded] = useState(false);

  // Helper function to dispatch custom events
  const dispatchCustomEvent = (eventName: string, detail?: any) => {
    const event = new CustomEvent(eventName, { detail });
    document.dispatchEvent(event);
  };
  
  // Define sticker types for the dropdown
  const stickerTypeOptions: { value: StickerType; label: string }[] = [
    { value: 'die-cut', label: 'Kujulõigatud kleebised' },
    { value: 'circle', label: 'Ümmargused kleebised' },
    { value: 'rectangle', label: 'Ristkülikukujulised kleebised' },
    { value: 'square', label: 'Ruudukujulised kleebised' },
    { value: 'oval', label: 'Ovaalsed kleebised' },
    { value: 'bumper', label: 'Kaitseraua kleebised' },
    { value: 'sticker-sheets', label: 'Kleebiselehed' },
    { value: 'kiss-cut', label: 'Kiss-cut kleebised' },
    { value: 'rounded-corner', label: 'Ümarate nurkadega kleebised' },
    { value: 'clear', label: 'Läbipaistvad kleebised' },
    { value: 'printed-transfer', label: 'Trükitud ülekandekleebised' },
    { value: 'transfer', label: 'Ülekandekleebised' },
    { value: 'vinyl-lettering', label: 'Vinüültähed' },
    { value: 'window-clings', label: 'Aknakleebised' },
    { value: 'front-adhesive', label: 'Esikülje-liimiga kleebised' },
    { value: 'fabric', label: 'Riidekleebised' }
  ];

  return (
    <section 
      className="hero-section"
      style={{
        backgroundImage: 'url(/images/decords-facility-hero.jpg)',
        backgroundSize: 'cover',
        backgroundPosition: 'center',
        backgroundRepeat: 'no-repeat',
        backgroundColor: '#f5f5f5'
      }}
    >
      {/* Semi-transparent overlay for better text readability */}
      <div className="hero-overlay"></div>

      {/* Hero content */}
      <div className="content-container">
        <div className="grid grid-cols-1 lg:grid-cols-2 gap-12 items-center">
          {/* Left side - Heading text with background overlay */}
          <div className="text-white max-w-lg">
            <div className="bg-black bg-opacity-80 p-6 rounded-xl">
              <h1 className="text-4xl md:text-5xl font-bold mb-4 leading-tight">
                Telli Kleebised Oma Kujundusega – Tasuta Tarne üle Eesti!
              </h1>
              <p className="text-xl md:text-2xl mb-6 font-light">
                Kvaliteetsed veekindlad kleebised ja vinüülkleebised igaks otstarbeks. Kleebiste tellimine oma disainiga - kiire kleebiste valmistamine Tallinnas ja tarne üle Eesti.
              </p>
            </div>
            <div className="flex flex-col sm:flex-row gap-4 mb-8">
              <div className="inline-flex items-center bg-emerald-600 text-white px-3 py-2 rounded-md shadow-lg hover:bg-emerald-700 transition-all transform hover:scale-105">
                <svg 
                  xmlns="http://www.w3.org/2000/svg" 
                  className="h-5 w-5 mr-2 flex-shrink-0" 
                  fill="none" 
                  viewBox="0 0 24 24" 
                  stroke="currentColor"
                >
                  <path 
                    strokeLinecap="round" 
                    strokeLinejoin="round" 
                    strokeWidth={2} 
                    d="M5 13l4 4L19 7" 
                  />
                </svg>
                <span className="font-bold text-xs whitespace-nowrap">Tasuta tarne</span>
              </div>
              <div className="inline-flex items-center bg-blue-600 text-white px-3 py-2 rounded-md shadow-lg hover:bg-blue-700 transition-all transform hover:scale-105">
                <svg 
                  xmlns="http://www.w3.org/2000/svg" 
                  className="h-5 w-5 mr-2 flex-shrink-0" 
                  fill="none" 
                  viewBox="0 0 24 24" 
                  stroke="currentColor"
                >
                  <path 
                    strokeLinecap="round" 
                    strokeLinejoin="round" 
                    strokeWidth={2} 
                    d="M12 8v4l3 3m6-3a9 9 0 11-18 0 9 9 0 0118 0z" 
                  />
                </svg>
                <span className="font-bold text-xs whitespace-nowrap">Kiire tootmine</span>
              </div>
            </div>
          </div>

          {/* Right side - Price calculator card */}
          <div className="bg-white rounded-xl shadow-2xl overflow-hidden">
            <div className="p-6">
              <h2 className="text-2xl font-bold mb-4 text-gray-800">Kalkulaator</h2>
              <div className="space-y-5">
                <div>
                  <label htmlFor="stickerType" className="block text-sm font-medium text-gray-700 mb-1">Kleebise tüüp</label>
                  <select
                    id="stickerType"
                    value={orderState.stickerType}
                    onChange={(e) => {
                      updateStickerType(e.target.value as StickerType);
                      dispatchCustomEvent('change:stickerType', { type: e.target.value });
                    }}
                    className="w-full rounded-md border-gray-300 shadow-sm focus:border-[#E74C3C] focus:ring-[#E74C3C] p-2 border"
                  >
                    {stickerTypeOptions.map((option) => (
                      <option key={option.value} value={option.value}>
                        {option.label}
                      </option>
                    ))}
                  </select>
                </div>
                
                <div className="grid grid-cols-1 sm:grid-cols-2 gap-4">
                  <div>
                    <label htmlFor="width" className="block text-sm font-medium text-gray-700 mb-1">Laius</label>
                    <div className="flex">
                      <input
                        type="number"
                        id="width"
                        min={1}
                        value={orderState.width}
                        onChange={(e) => {
                          updateDimensions('width', parseFloat(e.target.value));
                          dispatchCustomEvent('change:sizeField', { dimension: 'width', value: e.target.value });
                        }}
                        className="flex-1 rounded-l-md border-gray-300 shadow-sm focus:border-[#E74C3C] focus:ring-[#E74C3C] p-2 border"
                      />
                      <select 
                        value={orderState.widthUnit} 
                        onChange={(e) => updateDimensions('width', orderState.width, e.target.value as 'cm' | 'mm')}
                        className="w-[80px] rounded-r-md border-gray-300 shadow-sm focus:border-[#E74C3C] focus:ring-[#E74C3C] p-2 border"
                      >
                        <option value="cm">cm</option>
                        <option value="mm">mm</option>
                      </select>
                    </div>
                  </div>
                  
                  <div>
                    <label htmlFor="height" className="block text-sm font-medium text-gray-700 mb-1">Kõrgus</label>
                    <div className="flex">
                      <input
                        type="number"
                        id="height"
                        min={1}
                        value={orderState.height}
                        onChange={(e) => {
                          updateDimensions('height', parseFloat(e.target.value));
                          dispatchCustomEvent('change:sizeField', { dimension: 'height', value: e.target.value });
                        }}
                        className="flex-1 rounded-l-md border-gray-300 shadow-sm focus:border-[#E74C3C] focus:ring-[#E74C3C] p-2 border"
                      />
                      <select 
                        value={orderState.heightUnit} 
                        onChange={(e) => updateDimensions('height', orderState.height, e.target.value as 'cm' | 'mm')}
                        className="w-[80px] rounded-r-md border-gray-300 shadow-sm focus:border-[#E74C3C] focus:ring-[#E74C3C] p-2 border"
                      >
                        <option value="cm">cm</option>
                        <option value="mm">mm</option>
                      </select>
                    </div>
                  </div>
                </div>
                
                <div>
                  <label htmlFor="quantity" className="block text-sm font-medium text-gray-700 mb-1">Kogus</label>
                  <input
                    type="number"
                    id="quantity"
                    min={1}
                    value={orderState.quantity}
                    onChange={(e) => {
                      updateQuantity(parseInt(e.target.value));
                      // Make sure to use the event name that matches the listener in DecordsMascot
                      dispatchCustomEvent('change:quantityField', { value: e.target.value });
                    }}
                    className="rounded-md border-gray-300 shadow-sm focus:border-[#E74C3C] focus:ring-[#E74C3C] w-full p-2 border"
                  />
                </div>

                {/* Installation Options */}
                <div>
                  <label className="block text-sm font-medium text-gray-700 mb-3">Soovid ka paigaldust?</label>
                  <div className="space-y-3">
                    <label className="flex items-center">
                      <input
                        type="radio"
                        name="installation"
                        value="tallinn"
                        checked={orderState.installation === 'tallinn'}
                        onChange={(e) => updateInstallation('tallinn')}
                        className="w-4 h-4 text-[#E74C3C] bg-gray-100 border-gray-300 focus:ring-[#E74C3C] focus:ring-2"
                      />
                      <span className="ml-2 text-sm text-gray-900">Soovin paigaldust Tallinnas</span>
                    </label>
                    <label className="flex items-center">
                      <input
                        type="radio"
                        name="installation"
                        value="outside_tallinn"
                        checked={orderState.installation === 'outside_tallinn'}
                        onChange={(e) => updateInstallation('outside_tallinn')}
                        className="w-4 h-4 text-[#E74C3C] bg-gray-100 border-gray-300 focus:ring-[#E74C3C] focus:ring-2"
                      />
                      <span className="ml-2 text-sm text-gray-900">Soovin paigaldust väljaspool Tallinna (sõidukulu arvutatakse eraldi)</span>
                    </label>
                    <label className="flex items-center">
                      <input
                        type="radio"
                        name="installation"
                        value="none"
                        checked={orderState.installation === 'none'}
                        onChange={(e) => updateInstallation('none')}
                        className="w-4 h-4 text-[#E74C3C] bg-gray-100 border-gray-300 focus:ring-[#E74C3C] focus:ring-2"
                      />
                      <span className="ml-2 text-sm text-gray-900">Ei soovi paigaldust</span>
                    </label>
                  </div>
                  {orderState.installation === 'outside_tallinn' && (
                    <div className="mt-2 p-3 bg-yellow-50 border border-yellow-200 rounded-md">
                      <p className="text-sm text-yellow-800">
                        Sõidukulu lisandub, arvutame selle pärast aadressi täpsustamist
                      </p>
                    </div>
                  )}

                </div>
                
                <div className="bg-gray-50 p-4 rounded-lg">
                  <div className="flex justify-between items-center mb-2">
                    <span className="font-medium text-gray-600">Tüüp:</span>
                    <span className="font-medium text-gray-800">
                      {stickerTypeOptions.find(opt => opt.value === orderState.stickerType)?.label}
                    </span>
                  </div>
                  <div className="flex justify-between items-center mb-2">
                    <span className="font-medium text-gray-600">Suurus:</span>
                    <span className="font-medium text-gray-800">
                      {orderState.width} {orderState.widthUnit} × {orderState.height} {orderState.heightUnit}
                    </span>
                  </div>
                  <div className="flex justify-between items-center mb-2">
                    <span className="font-medium text-gray-600">Kogus:</span>
                    <span className="font-medium text-gray-800">{orderState.quantity} tk</span>
                  </div>
                  <div className="border-t border-gray-200 my-2 pt-2"></div>
                  <div className="flex justify-between items-center mb-1">
                    <span className="font-medium text-gray-600">Hind (koos KM-ga):</span>
                    <span className="text-2xl font-bold text-[#E74C3C]">{calculatePrice().toFixed(2)}€</span>
                  </div>
                  <div className="text-right text-xs text-gray-500 mb-3">
                    Hind sisaldab käibemaksu
                  </div>
                  <button
                    onClick={(e) => {
                      // Track checkout initiation with Facebook Pixel
                      try {
                        const fbqFunction = (window as any).fbq;
                        if (typeof fbqFunction === 'function') {
                          fbqFunction('track', 'InitiateCheckout', {
                            content_type: 'product',
                            content_category: 'Kleebised',
                            content_name: 'Kohandatud kleeps',
                            value: calculatePrice(),
                            currency: 'EUR'
                          });
                          console.log('Hero: Facebook Pixel InitiateCheckout event sent');
                        }
                      } catch (err) {
                        console.error('Hero: Error sending Facebook Pixel InitiateCheckout event', err);
                      }
                      
                      toggleModal();
                      dispatchCustomEvent('click:order');
                    }}
                    className="w-full bg-[#E74C3C] hover:bg-[#C0392B] text-white font-medium py-3 px-4 rounded-md transition duration-200"
                  >
                    Telli kohe
                  </button>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
    </section>
  );
};

export default Hero;
